module WeatherModel
  module SourceSchema

    AqiForecast = {
      sort: 'Aqi',
      table_name: :aqi_forecasts,
      schema: {
        datetime: :datetime,
        prompt: :string,
        list: :text
      },
      options: {
        index: %i[datetime],
        expire: 2 * 24 * 60 * 60,
        unique: nil,
        belongs_to: nil,
        has_many: nil,
        json_column: :list
      },
      factory_name: :aqi_forecast,
      factory: {
        datetime: Time.parse('2011-11-11 11:11'),
        prompt: '',
        list: [
          {
            "period"=>"今天夜间（20时—06时）",
            "aqi"=>"35-55",
            "level"=>"优到良",
            "pripoll"=>"PM10"
          }, {
            "period"=>"明天上午（06时—12时）",
            "aqi"=>"35-55",
            "level"=>"优到良",
            "pripoll"=>"PM10"
          }, {
            "period"=>"明天下午（12时—20时）",
            "aqi"=>"45-65",
            "level"=>"优到良",
            "pripoll"=>"O3"
          }, {
            "period"=>"明天夜间（20时—06时）",
            "aqi"=>"35-55",
            "level"=>"优到良",
            "pripoll"=>"PM10"
          }, {
            "period"=>"后天白天（06时—20时）",
            "aqi"=>"55-75",
            "level"=>"良",
            "pripoll"=>"O3"
          }
        ]
      }
    }

    AqiLive = {
      sort: 'Aqi',
      table_name: :aqi_lives,
      schema: {
        aqi: :integer,
        area: :string,
        co: :float,
        co_24h: :float,
        no2: :float,
        no2_24h: :float,
        o3: :float,
        o3_24h: :float,
        o3_8h: :float,
        o3_8h_24h: :float,
        pm10: :float,
        pm10_24h: :float,
        pm2_5: :float,
        pm2_5_24h: :float,
        position_name: :string,
        primary_pollutant: :string,
        quality: :string,
        so2: :float,
        so2_24h: :float,
        station_code: :string,
        time_point: :datetime,
      },
      options: {
        index: %i[area time_point],
        expire: 2 * 24 * 60 * 60,
        unique: nil,
        belongs_to: nil,
        has_many: nil,
        json_column: :nil,
      },
      factory_name: :aqi_live,
      factory: {
        "aqi" => 46,
        "area" => "宜宾",
        "co" => 1.1,
        "co_24h" => 1.2,
        "no2" => 20,
        "no2_24h" => 22,
        "o3" => 73,
        "o3_24h" => 129,
        "o3_8h" => 45,
        "o3_8h_24h" => 53,
        "pm10" => 45,
        "pm10_24h" => 60,
        "pm2_5" => 32,
        "pm2_5_24h" => 42,
        "position_name" => "市政府",
        "primary_pollutant" => nil,
        "quality" => "优",
        "so2" => 10,
        "so2_24h" => 13,
        "station_code" => "1885A",
        "time_point" => Time.parse("2017-05-21 16:00:00"),
      },
    }
  end
end
